==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiCore/QPluginParsedMetaData_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/private/qfactoryloader_p.h>
#include <QtCore/QVariant>
#include <QtCore/qcbormap.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambiCore/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QPluginParsedMetaData(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QPluginParsedMetaData")
    QPluginParsedMetaData *_ptr = reinterpret_cast<QPluginParsedMetaData *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QPluginParsedMetaData()
void __qt_construct_QPluginParsedMetaData_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QPluginParsedMetaData()")
    Q_UNUSED(__java_arguments)
    QPluginParsedMetaData *__qt_this = new(__qtjambi_ptr) QPluginParsedMetaData();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QPluginParsedMetaData
void __qt_destruct_QPluginParsedMetaData(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QPluginParsedMetaData")
    reinterpret_cast<QPluginParsedMetaData*>(ptr)->~QPluginParsedMetaData();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QPluginParsedMetaData::QPluginParsedMetaData()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_internal_QPluginParsedMetaData_initialize_1native__Lio_qt_core_internal_QPluginParsedMetaData_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPluginParsedMetaData::QPluginParsedMetaData()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QPluginParsedMetaData_0, sizeof(QPluginParsedMetaData), typeid(QPluginParsedMetaData), false, &deleter_QPluginParsedMetaData, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QPluginParsedMetaData::errorString()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_internal_QPluginParsedMetaData_errorString_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QPluginParsedMetaData *__qt_this = QtJambiAPI::objectFromNativeId<QPluginParsedMetaData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPluginParsedMetaData::errorString()const", __qt_this)
        QString __qt_return_value = __qt_this->errorString();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPluginParsedMetaData::isError()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_internal_QPluginParsedMetaData_isError_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QPluginParsedMetaData *__qt_this = QtJambiAPI::objectFromNativeId<QPluginParsedMetaData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPluginParsedMetaData::isError()const", __qt_this)
        __java_return_value = __qt_this->isError();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPluginParsedMetaData::operator==(QPluginParsedMetaData,QPluginParsedMetaData)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_internal_QPluginParsedMetaData_equals_1native_1cref_1QPluginParsedMetaData__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID value21)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QPluginParsedMetaData *__qt_this = QtJambiAPI::objectFromNativeId<QPluginParsedMetaData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPluginParsedMetaData::operator==(QPluginParsedMetaData,QPluginParsedMetaData)", __qt_this)
        const QPluginParsedMetaData& __qt_value21 = QtJambiAPI::valueReferenceFromNativeId<QPluginParsedMetaData>(value21);
        __java_return_value = (*__qt_this) == __qt_value21;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPluginParsedMetaData::toCbor()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_internal_QPluginParsedMetaData_toCbor_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QPluginParsedMetaData *__qt_this = QtJambiAPI::objectFromNativeId<QPluginParsedMetaData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPluginParsedMetaData::toCbor()const", __qt_this)
        QCborMap __qt_return_value = __qt_this->toCbor();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeCustomStructors)
void custom_copy_constructor_QPluginParsedMetaData(const QtPrivate::QMetaTypeInterface *metaTypeInterface, void* placement, const void * __in_var)
{
    Q_UNUSED(metaTypeInterface)
    Q_UNUSED(placement)
    const QPluginParsedMetaData* copy = static_cast<const QPluginParsedMetaData*>(__in_var);
    Q_UNUSED(copy)
    new(placement) QCborValue(copy->toCbor());
}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_internal_QPluginParsedMetaData_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QPluginParsedMetaData *__qt_this = QtJambiAPI::objectFromNativeId<QPluginParsedMetaData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(quint64(hashValue) ^ quint64(hashValue) >> 32);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_internal_QPluginParsedMetaData_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QPluginParsedMetaData *__qt_this = QtJambiAPI::objectFromNativeId<QPluginParsedMetaData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QPluginParsedMetaData(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QPluginParsedMetaData>("QPluginParsedMetaData", "io/qt/core/internal/QPluginParsedMetaData");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QPluginParsedMetaData, {
        ConstructorInfo(&__qt_construct_QPluginParsedMetaData_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QPluginParsedMetaData);
    registerMetaType<QPluginParsedMetaData>("QPluginParsedMetaData", QtJambiPrivate::QMetaTypeInterfaceFunctions<QPluginParsedMetaData>::defaultCtr, &custom_copy_constructor_QPluginParsedMetaData, QtJambiPrivate::QMetaTypeInterfaceFunctions<QPluginParsedMetaData>::moveCtr);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiCore/QPluginParsedMetaData_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/private/qfactoryloader_p.h>
#include <QtCore/QVariant>
#include <QtCore/qcbormap.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambiCore/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QPluginParsedMetaData(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QPluginParsedMetaData")
    QPluginParsedMetaData *_ptr = reinterpret_cast<QPluginParsedMetaData *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QPluginParsedMetaData()
void __qt_construct_QPluginParsedMetaData(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QPluginParsedMetaData()")
    Q_UNUSED(__java_arguments)
    QPluginParsedMetaData *__qt_this = new(__qtjambi_ptr) QPluginParsedMetaData();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QPluginParsedMetaData::QPluginParsedMetaData()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_internal_QPluginParsedMetaData_initialize_1native__Lio_qt_core_internal_QPluginParsedMetaData_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPluginParsedMetaData::QPluginParsedMetaData()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QPluginParsedMetaData, sizeof(QPluginParsedMetaData), typeid(QPluginParsedMetaData), false, &deleter_QPluginParsedMetaData, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QPluginParsedMetaData(QPluginParsedMetaData)
void __qt_construct_QPluginParsedMetaData_cref_QPluginParsedMetaData(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QPluginParsedMetaData(QPluginParsedMetaData)")
    jobject other0 = __java_arguments[0].l;
    const QPluginParsedMetaData& __qt_other0 = qtjambi_cast<const QPluginParsedMetaData& >(__jni_env, other0);
    QPluginParsedMetaData *__qt_this = new(__qtjambi_ptr) QPluginParsedMetaData(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QPluginParsedMetaData::QPluginParsedMetaData(QPluginParsedMetaData)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_internal_QPluginParsedMetaData_initialize_1native__Lio_qt_core_internal_QPluginParsedMetaData_2Lio_qt_core_internal_QPluginParsedMetaData_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPluginParsedMetaData::QPluginParsedMetaData(QPluginParsedMetaData)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QPluginParsedMetaData_cref_QPluginParsedMetaData, sizeof(QPluginParsedMetaData), typeid(QPluginParsedMetaData), false, &deleter_QPluginParsedMetaData, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QPluginParsedMetaData
void __qt_destruct_QPluginParsedMetaData(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QPluginParsedMetaData")
    reinterpret_cast<QPluginParsedMetaData*>(ptr)->~QPluginParsedMetaData();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QPluginParsedMetaData::errorString()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_internal_QPluginParsedMetaData_errorString_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QPluginParsedMetaData *__qt_this = QtJambiAPI::objectFromNativeId<QPluginParsedMetaData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPluginParsedMetaData::errorString()const", __qt_this)
        QString __qt_return_value = __qt_this->errorString();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPluginParsedMetaData::isError()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_internal_QPluginParsedMetaData_isError_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QPluginParsedMetaData *__qt_this = QtJambiAPI::objectFromNativeId<QPluginParsedMetaData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPluginParsedMetaData::isError()const", __qt_this)
        __java_return_value = __qt_this->isError();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPluginParsedMetaData::operator==(QPluginParsedMetaData,QPluginParsedMetaData)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_internal_QPluginParsedMetaData_equals_1native_1cref_1QPluginParsedMetaData__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID value21)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QPluginParsedMetaData *__qt_this = QtJambiAPI::objectFromNativeId<QPluginParsedMetaData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPluginParsedMetaData::operator==(QPluginParsedMetaData,QPluginParsedMetaData)", __qt_this)
        const QPluginParsedMetaData& __qt_value21 = QtJambiAPI::valueReferenceFromNativeId<QPluginParsedMetaData>(value21);
        __java_return_value = (*__qt_this) == __qt_value21;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPluginParsedMetaData::toCbor()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_internal_QPluginParsedMetaData_toCbor_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QPluginParsedMetaData *__qt_this = QtJambiAPI::objectFromNativeId<QPluginParsedMetaData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPluginParsedMetaData::toCbor()const", __qt_this)
        QCborMap __qt_return_value = __qt_this->toCbor();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeCustomStructors)
void custom_copy_constructor_QPluginParsedMetaData(const QtPrivate::QMetaTypeInterface *metaTypeInterface, void* placement, const void * __in_var)
{
    Q_UNUSED(metaTypeInterface)
    Q_UNUSED(placement)
    const QPluginParsedMetaData* copy = static_cast<const QPluginParsedMetaData*>(__in_var);
    Q_UNUSED(copy)
    new(placement) QCborValue(copy->toCbor());
}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_internal_QPluginParsedMetaData_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QPluginParsedMetaData *__qt_this = QtJambiAPI::objectFromNativeId<QPluginParsedMetaData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(quint64(hashValue) ^ quint64(hashValue) >> 32);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_internal_QPluginParsedMetaData_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QPluginParsedMetaData *__qt_this = QtJambiAPI::objectFromNativeId<QPluginParsedMetaData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QPluginParsedMetaData(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QPluginParsedMetaData>("QPluginParsedMetaData", "io/qt/core/internal/QPluginParsedMetaData");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QPluginParsedMetaData, {
        ConstructorInfo(&__qt_construct_QPluginParsedMetaData, nullptr)
       ,ConstructorInfo(&__qt_construct_QPluginParsedMetaData_cref_QPluginParsedMetaData, "Lio/qt/core/internal/QPluginParsedMetaData;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QPluginParsedMetaData);
    registerMetaType<QPluginParsedMetaData>("QPluginParsedMetaData", QtJambiPrivate::QMetaTypeInterfaceFunctions<QPluginParsedMetaData>::defaultCtr, &custom_copy_constructor_QPluginParsedMetaData, QtJambiPrivate::QMetaTypeInterfaceFunctions<QPluginParsedMetaData>::moveCtr);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
